@@ -172,7 +172,7 @@
   </section>
 </chapter>
 
-   $Date: 2013-03-04 14:47:29 +0000 (Mon, 04 Mar 2013) $ $Revision: 36261 $
+   $Date: 2013-09-05 13:48:53 +0100 (Thu, 05 Sep 2013) $ $Revision: 37042 $
    */ 
 
 #ifndef	INCLUDED_SQLClient_H
@@ -233,7 +233,9 @@ extern NSString * const SQLClientDidDisconnectNotification;
  * A nil value is represented by [NSNull null].<br />
  * Keys must be unique string values (case insensitive comparison).
  */
-+ (id) newWithValues: (id*)v keys: (NSString**)k count: (unsigned int)c;
++ (id) newWithValues: (id*)v
+		keys: (NSString**)k
+	       count: (unsigned int)c;
 
 /**
  * Returns an array containing the names of all the fields in the record.
@@ -298,7 +300,7 @@ extern NSString * const SQLClientDidDisconnectNotification;
  * The exclude set is used to specify objects to exclude from the
  * calculation (to prevent recursion etc).
  */
-- (unsigned) sizeInBytes: (NSMutableSet*)exclude;
+- (NSUInteger) sizeInBytes: (NSMutableSet*)exclude;
 @end
 
 extern NSString	*SQLException;
@@ -367,6 +369,12 @@ SQLCLIENT_PRIVATE
    * set by the -begin, -commit or -rollback methods.
    */
   BOOL			_inTransaction;	/** Are we inside a transaction? */
+  /**
+   * A flag indicating whether wleading and trailing white space in values
+   * read from the database shoud automatically be removed.<br />
+   * This should only be modified by the -setShouldTrim: method.
+   */
+  BOOL                  _shouldTrim;    /** Should whitespace be trimmed? */
   NSString		*_name;		/** Unique identifier for instance */
   NSString		*_client;	/** Identifier within backend */
   NSString		*_database;	/** The configured database name/host */
@@ -638,10 +646,11 @@ SQLCLIENT_PRIVATE
  * then 'User' may be used instead.<br />
  * Password ... is the name of the database user password, if it is
  * missing then 'Password' may be used instead.<br />
- * missing then 'Password' may be used instead.<br />
  * ServerType ... is the name of the backend server to be used ... by
  * convention the name of a bundle containing the interface to that backend.
  * If this is missing then 'Postgres' is used.<br />
+ * The database name may be of the format 'name@host:port' when you wish to
+ * connect to a database on a different host over the network.
  */
 - (id) initWithConfiguration: (NSDictionary*)config
 			name: (NSString*)reference;
@@ -820,6 +829,12 @@ SQLCLIENT_PRIVATE
  */
 - (void) setPassword: (NSString*)s;
 
+/** Sets an internal flag to indicate whether leading and trailing white
+ * space characters should be removed from values retrieved from the
+ * database by the receiver.
+ */
+- (void) setShouldTrim: (BOOL)aFlag;
+
 /**
  * Set the database user for this object.<br />
  * This is called automatically to configure the connection ...
@@ -1564,7 +1579,9 @@ SQLCLIENT_PRIVATE
  * It's OK to return a nil object since we ignore the -addObject:
  * argument.
  */
-- (id) newWithValues: (id*)values keys: (id*)keys count: (unsigned int)count; 
+- (id) newWithValues: (id*)values
+		keys: (NSString**)keys
+	       count: (unsigned int)count; 
 @end
 
 /* A helper for building a collection of singletons from an SQL query
@@ -1576,7 +1593,9 @@ SQLCLIENT_PRIVATE
  * See [SQLClient-simpleQuery:recordType:listType:] also.
  */
 @interface SQLSingletonBuilder : NSObject
-- (id) newWithValues: (id*)values keys: (id*)keys count: (unsigned int)count; 
+- (id) newWithValues: (id*)values
+		keys: (NSString**)keys
+	       count: (unsigned int)count; 
 @end
 
 #endif
